@@ -9,20 +9,15 @@ import argparse
 def get_pod_ids(api_token, account_name, account_id, model_name):
     get_pods_json = {"model_name":model_name,"account_id":account_id,"api_token":api_token,"account_name":account_name}
     get_pods = requests.post('https://get-pods-fgkue36c2q-uc.a.run.app', json = get_pods_json, headers={'Authorization':api_token})
-    get_pods_response = json.loads(get_pods.text)
-    get_pods_content = get_pods_response["response"]
-    get_pods_k8s = yaml.safe_load(get_pods_content)
-
+   
     try:
-        pod_names = []
-        for i in get_pods_k8s["items"]:
-            pod_names.append(i["metadata"]["name"])
+        get_pods_response = json.loads(get_pods.text)
+        get_pods_content = get_pods_response['response']
+        return get_pods_content
     except Exception as e:
         print(f"ERROR. Unable to get pod names with exception: {e}")
         return
 
-    return pod_names
-
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("--api_token", help="Your pyq API token", required=True)
